==> rust-hdl-0.11.5.crate: rust-hdl-0.11.5/src/widgets/prelude.rs <==
pub use crate::declare_async_fifo;
pub use crate::declare_expanding_fifo;
pub use crate::declare_narrowing_fifo;
pub use crate::declare_sync_fifo;
pub use crate::widgets::fifo::async_fifo::AsynchronousFIFO;
//pub use crate::widgets::bidirectional_bus::{
//    BidiBusD, BidiBusM, BidiMaster, BidiSimulatedDevice, FifoBus, FifoBusIn,
//};
pub use crate::widgets::delay_line::DelayLine;
pub use crate::widgets::dff::DFF;
pub use crate::widgets::edge_detector::EdgeDetector;
pub use crate::widgets::fifo::cross_fifo::CrossNarrowFIFO;
pub use crate::widgets::fifo::cross_fifo::CrossWidenFIFO;
pub use crate::widgets::fifo::fifo_expander_n::FIFOExpanderN;
pub use crate::widgets::fifo::fifo_expander_n::WordOrder;
pub use crate::widgets::fifo::fifo_reducer::FIFOReducer;
pub use crate::widgets::fifo::fifo_reducer_n::FIFOReducerN;
pub use crate::widgets::fifo::fifo_register::RegisterFIFO;
pub use crate::widgets::fifo::sync_fifo::SynchronousFIFO;
pub use crate::widgets::i2c::i2c_driver::I2CConfig;
pub use crate::widgets::i2c::i2c_target::I2CTarget;
pub use crate::widgets::mac_fir::MultiplyAccumulateSymmetricFiniteImpulseResponseFilter;
pub use crate::widgets::open_drain::OpenDrainBuffer;
pub use crate::widgets::pulser::Pulser;
pub use crate::widgets::pwm::PulseWidthModulator;
pub use crate::widgets::ramrom::ram::RAM;
pub use crate::widgets::ramrom::rom::ROM;
pub use crate::widgets::ramrom::sync_rom::SyncROM;
pub use crate::widgets::sdram::cmd::SDRAMCommand;
pub use crate::widgets::sdram::fifo_controller::SDRAMFIFOController;
pub use crate::widgets::sdram::timings::MemoryTimings;
pub use crate::widgets::shot::Shot;
pub use crate::widgets::spi::master::SPIWiresSlave;
pub use crate::widgets::spi::master::{SPIConfig, SPIMaster, SPIWiresMaster};
pub use crate::widgets::spi::master_dynamic_mode::{SPIConfigDynamicMode, SPIMasterDynamicMode};
pub use crate::widgets::spi::mux::{MuxMasters, MuxSlaves};
pub use crate::widgets::spi::slave::SPISlave;
pub use crate::widgets::strobe::Strobe;
pub use crate::widgets::synchronizer::{
    BitSynchronizer, SyncReceiver, SyncSender, VectorSynchronizer,
};
pub use crate::widgets::tristate::TristateBuffer;
pub use crate::{
    i2c_begin_read, i2c_begin_write, i2c_end_transmission, i2c_read, i2c_read_last, i2c_write,
};

==> rust-hdl-0.15.0.crate: rust-hdl-0.15.0/src/widgets/prelude.rs <==
pub use crate::declare_async_fifo;
pub use crate::declare_expanding_fifo;
pub use crate::declare_narrowing_fifo;
pub use crate::declare_sync_fifo;
pub use crate::widgets::fifo::async_fifo::AsynchronousFIFO;
//pub use crate::widgets::bidirectional_bus::{
//    BidiBusD, BidiBusM, BidiMaster, BidiSimulatedDevice, FifoBus, FifoBusIn,
//};
pub use crate::widgets::delay_line::DelayLine;
pub use crate::widgets::dff::DFF;
pub use crate::widgets::edge_detector::EdgeDetector;
pub use crate::widgets::fifo::cross_fifo::CrossNarrowFIFO;
pub use crate::widgets::fifo::cross_fifo::CrossWidenFIFO;
pub use crate::widgets::fifo::fifo_expander_n::FIFOExpanderN;
pub use crate::widgets::fifo::fifo_expander_n::WordOrder;
pub use crate::widgets::fifo::fifo_reducer::FIFOReducer;
pub use crate::widgets::fifo::fifo_reducer_n::FIFOReducerN;
pub use crate::widgets::fifo::fifo_register::RegisterFIFO;
pub use crate::widgets::fifo::sync_fifo::SynchronousFIFO;
pub use crate::widgets::i2c::i2c_driver::I2CConfig;
pub use crate::widgets::i2c::i2c_target::I2CTarget;
pub use crate::widgets::mac_fir::MultiplyAccumulateSymmetricFiniteImpulseResponseFilter;
pub use crate::widgets::open_drain::OpenDrainBuffer;
pub use crate::widgets::png::lfsr::LFSRSimple;
pub use crate::widgets::pulser::Pulser;
pub use crate::widgets::pwm::PulseWidthModulator;
pub use crate::widgets::ramrom::ram::RAM;
pub use crate::widgets::ramrom::rom::ROM;
pub use crate::widgets::ramrom::sync_rom::SyncROM;
pub use crate::widgets::sdram::basic_controller::{OutputBuffer, SDRAMBaseController};
pub use crate::widgets::sdram::cmd::SDRAMCommand;
pub use crate::widgets::sdram::timings::MemoryTimings;
pub use crate::widgets::sdram::SDRAMDriver;
pub use crate::widgets::shot::Shot;
pub use crate::widgets::spi::master::SPIWiresSlave;
pub use crate::widgets::spi::master::{SPIConfig, SPIMaster, SPIWiresMaster};
pub use crate::widgets::spi::master_dynamic_mode::{SPIConfigDynamicMode, SPIMasterDynamicMode};
pub use crate::widgets::spi::mux::{MuxMasters, MuxSlaves};
pub use crate::widgets::spi::slave::SPISlave;
pub use crate::widgets::strobe::Strobe;
pub use crate::widgets::synchronizer::{
    BitSynchronizer, SyncReceiver, SyncSender, VectorSynchronizer,
};
pub use crate::widgets::tristate::TristateBuffer;
pub use crate::{
    i2c_begin_read, i2c_begin_write, i2c_end_transmission, i2c_read, i2c_read_last, i2c_write,
};
pub use crate::widgets::sdram::fifo_sdram::SDRAMFIFOController;
